import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { INeedItem } from '../../../../../utils/orientationUtils';
import { OnlineDemarche } from '../../../enums/onlineDemarche.enum';

@Component({
  selector: 'app-accompaniment-type',
  templateUrl: './accompaniment-type.component.html',
})
export class AccompanimentTypeComponent implements OnInit {
  @Input() form: UntypedFormGroup;
  @Output() checkValidation = new EventEmitter<any>();

  public selected: string;
  public accompanimentTypes: INeedItem[] = [
    {
      title: "Trouver une structure proposant l'accompagnement adapté",
      hint: 'La personne pourra prendre contact avec la structure ou s’y rendre directement',
      key: OnlineDemarche.structureList,
    },
    {
      title: 'Prendre RDV auprès d’un conseiller ou une conseillère numérique',
      hint: 'La demande de RDV sera transmise à un conseiller numérique',
      key: OnlineDemarche.appointment,
    },
    {
      title: 'Choisir un créneau de médiation numérique à distance',
      hint: 'La personne sera recontactée par téléphone sur le créneau de son choix',
      key: OnlineDemarche.onlineMediation,
    },
  ];
  ngOnInit(): void {
    if (this.form.get('accompanimentType').value !== '') {
      this.selected = this.form.get('accompanimentType').value;
    }
    this.checkValidation.emit();
  }

  public handleSelect(event: string): void {
    this.selected = event;
    this.form.get('accompanimentType').patchValue(event);
    this.checkValidation.emit();
  }
}
